;;; skk-tutcdef.el --- SKK TUT-code default definition.
;; Copyright (C) 1999 GUNJI Takao <gunji@sils.shoin.ac.jp>

;; Author: GUNJI Takao <gunji@sils.shoin.ac.jp>
;; Maintainer: Mikio Nakajima <minakaji@osaka.email.ne.jp>
;; Version: $Id: skk-tutcdef.el,v 1.8 1999/10/03 12:18:31 minakaji Exp $
;; Keywords: japanese
;; Last Modified: $Date: 1999/10/03 12:18:31 $

;; This file is not part of SKK yet.

;; SKK is free software; you can redistribute it and/or modify it under
;; the terms of the GNU General Public License as published by the Free
;; Software Foundation; either versions 2, or (at your option) any later
;; version.

;; SKK is distributed in the hope that it will be useful but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
;; License for more details.

;; You should have received a copy of the GNU General Public License
;; along with SKK, see the file COPYING.  If not, write to the Free
;; Software Foundation Inc., 59 Temple Place - Suite 330, Boston,
;; MA 02111-1307, USA.

;;; Commentary:
;; Following people contributed modifications to skk.el (Alphabetical order):
;;      Mikio Nakajima <minakaji@osaka.email.ne.jp>

;;; Code:
(eval-when-compile (require 'skk) (require 'skk-tutcode))

(define-key skk-j-mode-map "\C-l" 'skk-latin-mode)
(setq skk-auto-insert-paren t)
(setq skk-try-completion-char ?\016)	; \C-n
(setq skk-latin-mode-string " sTUT")
(setq skk-hiragana-mode-string " ｓたっと")
(setq skk-katakana-mode-string " ｓタット")
(setq skk-jisx0208-latin-mode-string " ｓＴＵＴ")
(setq skk-abbrev-mode-string " sた")
(setq skk-start-henkan-char ?\^@)

(setq skk-kana-rom-vector
  ["r" "r" "r" "r" "r" "r" "r" "r" "r" "r" "e" "e" "e" "e" "e" "e"
   "e" "e" "e" "e" "s" "s" "s" "s" "s" "s" "s" "s" "s" "s" "d" "d"
   "d" "d" "d" "d" "d" "d" "d" "d" "d" "f" "f" "f" "f" "f" "t" "t"
   "t" "t" "t" "t" "t" "t" "t" "t" "t" "t" "t" "t" "t" "w" "w" "w"
   "w" "w" "q" "q" "q" "q" "q" "q" "g" "g" "g" "g" "g" "a" "a" "a"
   "a" "a" "f"] )

(setq skk-rom-kana-base-rule-list
 '(("$" nil skk-tutcode-display-code)
   ("'" nil skk-abbrev-mode)
   ("@" nil skk-today)
   ("L" nil skk-jisx0208-latin-mode)
   ("Q" nil skk-set-henkan-point-subr)
   ("X" nil skk-purge-from-jisyo)
   ("\\" nil skk-tutcode-mode-off)
   ("\t" nil skk-toggle-kana)
   ("^" nil skk-input-by-code-or-menu) ))

(if (and (eq skk-emacs-type 'xemacs) (= emacs-major-version 20))
    (progn
      (setq skk-rom-kana-base-rule-list
	    (delete '("\t" nil skk-toggle-kana) skk-rom-kana-base-rule-list) )
      (define-key skk-j-mode-map "\t" 'skk-toggle-kana) ))

;; The first few entries are necessary to disable special treatments of
(setq skk-rom-kana-rule-list
      '(
	("rk" nil ("ア" . "あ")) ("rlk" nil ("ァ" . "ぁ")) ("ek" nil ("カ" . "か"))
	("elk" nil ("ガ" . "が")) ("sk" nil ("サ" . "さ")) ("slk" nil ("ザ" . "ざ"))
	("dk" nil ("タ" . "た")) ("dlk" nil ("ダ" . "だ")) ("fk" nil ("ナ" . "な"))
	("tk" nil ("ハ" . "は")) ("tlk" nil ("バ" . "ば")) ("tltk" nil ("パ" . "ぱ"))
	("wk" nil ("マ" . "ま")) ("qk" nil ("ヤ" . "や")) ("qlk" nil ("ャ" . "ゃ"))
	("gk" nil ("ラ" . "ら")) ("ak" nil ("ワ" . "わ")) ("alk" nil ("ヮ" . "ゎ"))
	("ri" nil ("イ" . "い")) ("rli" nil ("ィ" . "ぃ")) ("ei" nil ("キ" . "き"))
	("eli" nil ("ギ" . "ぎ")) ("si" nil ("シ" . "し")) ("sli" nil ("ジ" . "じ"))
	("di" nil ("チ" . "ち")) ("dli" nil ("ヂ" . "ぢ")) ("fi" nil ("ニ" . "に"))
	("ti" nil ("ヒ" . "ひ")) ("tli" nil ("ビ" . "び")) ("tlti" nil ("ピ" . "ぴ"))
	("wi" nil ("ミ" . "み")) ("gi" nil ("リ" . "り")) ("ai" nil ("ヰ" . "ゐ"))
	("ru" nil ("ウ" . "う")) ("rlu" nil ("ゥ" . "ぅ")) ("eu" nil ("ク" . "く"))
	("elu" nil ("グ" . "ぐ")) ("su" nil ("ス" . "す")) ("slu" nil ("ズ" . "ず"))
	("du" nil ("ツ" . "つ")) ("dlu" nil ("ッ" . "っ")) ("dldu" nil ("ヅ" . "づ"))
	("fu" nil ("ヌ" . "ぬ")) ("tu" nil ("フ" . "ふ")) ("tlu" nil ("ブ" . "ぶ"))
	("tltu" nil ("プ" . "ぷ")) ("wu" nil ("ム" . "む")) ("qu" nil ("ユ" . "ゆ"))
	("qlu" nil ("ュ" . "ゅ")) ("gu" nil ("ル" . "る"))
	("rh" nil ("エ" . "え")) ("rlh" nil ("ェ" . "ぇ")) ("eh" nil ("ケ" . "け"))
	("elh" nil ("ゲ" . "げ")) ("sh" nil ("セ" . "せ")) ("slh" nil ("ゼ" . "ぜ"))
	("dh" nil ("テ" . "て")) ("dlh" nil ("デ" . "で")) ("fh" nil ("ネ" . "ね"))
	("th" nil ("ヘ" . "へ")) ("tlh" nil ("ベ" . "べ")) ("tlth" nil ("ペ" . "ぺ"))
	("wh" nil ("メ" . "め")) ("gh" nil ("レ" . "れ")) ("ah" nil ("ヱ" . "ゑ"))
	("rj" nil ("オ" . "お")) ("rlj" nil ("ォ" . "ぉ")) ("ej" nil ("コ" . "こ"))
	("elj" nil ("ゴ" . "ご")) ("sj" nil ("ソ" . "そ")) ("slj" nil ("ゾ" . "ぞ"))
	("dj" nil ("ト" . "と")) ("dlj" nil ("ド" . "ど")) ("fj" nil ("ノ" . "の"))
	("tj" nil ("ホ" . "ほ")) ("tlj" nil ("ボ" . "ぼ")) ("tltj" nil ("ポ" . "ぽ"))
	("wj" nil ("モ" . "も")) ("qj" nil ("ヨ" . "よ")) ("qlj" nil ("ョ" . "ょ"))
	("gj" nil ("ロ" . "ろ")) ("aj" nil ("ヲ" . "を")) ("fl" nil ("ン" . "ん"))
	("rlru" nil "ヴ") ("eleh" nil "ヶ") ("elek" nil "ヵ")
	("f " nil skk-current-kuten) ("d " nil skk-current-touten)
	("/ " nil "／")
	("q " nil "“") ("w " nil "〒") ("e " nil "ー")
	("r " nil "（") ("u " nil "）") ("i " nil "…")
	("o " nil "・") ("p " nil "”") ("a " nil "‘")
	("s " nil "☆") ("j " nil "々") ("k " nil "※")
	("l " nil "＼") ("; " nil "’") ("z " nil "〆")
	("x " nil "§") ("c " nil "〇") ("v " nil "【")
	("m " nil "】") (", " nil "《") (". " nil "》")
	("t " nil "「") ("y " nil "」") ("g " nil "『")
	("h " nil "』") ("b " nil "←") ("n " nil "→")
	("zz" nil "雑") ("xz" nil "推") ("cz" nil "渡")
	("vz" nil "効") ("bz" nil "宇") ("nz" nil "振")
	("mz" nil "鉱") (",z" nil "敷") ("az" nil "星")
	("sz" nil "許") ("dz" nil "街") ("fz" nil "鈴")
	("gz" nil "帝") ("hz" nil "精") ("jz" nil "友")
	("kz" nil "収") ("qz" nil "返") ("wz" nil "競")
	("ez" nil "母") ("rz" nil "熱") ("tz" nil "退")
	("yz" nil "企") ("uz" nil "服") ("iz" nil "鋼")
	(".z" nil "融") ("/z" nil "浦") ("lz" nil "寺")
	(";z" nil "履") ("oz" nil "停") ("pz" nil "州")
	("zx" nil "刊") ("xx" nil "徳") ("cx" nil "登")
	("vx" nil "冷") ("bx" nil "響") ("nx" nil "津")
	("mx" nil "塚") (",x" nil "尾") ("ax" nil "族")
	("sx" nil "従") ("dx" nil "堂") ("fx" nil "兵")
	("gx" nil "監") ("hx" nil "浜") ("jx" nil "戸")
	("kx" nil "料") ("qx" nil "祭") ("wx" nil "訪")
	("ex" nil "諸") ("rx" nil "修") ("tx" nil "版")
	("yx" nil "伊") ("ux" nil "週") ("ix" nil "階")
	(".x" nil "竹") ("/x" nil "泉") ("lx" nil "火")
	(";x" nil "坂") ("ox" nil "労") ("px" nil "板")
	("zc" nil "酒") ("xc" nil "御") ("cc" nil "守")
	("vc" nil "程") ("bc" nil "史") ("nc" nil "草")
	("mc" nil "条") (",c" nil "栄") ("ac" nil "賃")
	("sc" nil "晴") ("dc" nil "独") ("fc" nil "観")
	("gc" nil "変") ("hc" nil "南") ("jc" nil "谷")
	("kc" nil "道") ("qc" nil "曇") ("wc" nil "注")
	("ec" nil "免") ("rc" nil "茶") ("tc" nil "昨")
	("yc" nil "科") ("uc" nil "屋") ("ic" nil "映")
	(".c" nil "庫") ("/c" nil "波") ("lc" nil "共")
	(";c" nil "江") ("oc" nil "阪") ("pc" nil "昇")
	("nv" nil "芝") ("mv" nil "幸") (",v" nil "玉")
	("hv" nil "横") ("jv" nil "台") ("kv" nil "橋")
	("yv" nil "央") ("uv" nil "池") ("iv" nil "制")
	(".v" nil "曜") ("/v" nil "環") ("lv" nil "武")
	(";v" nil "宝") ("ov" nil "証") ("pv" nil "浅")
	("nb" nil "岩") ("mb" nil "城") (",b" nil "永")
	("hb" nil "軍") ("jb" nil "土") ("kb" nil "神")
	("yb" nil "昭") ("ub" nil "宮") ("ib" nil "職")
	(".b" nil "秋") ("/b" nil "陸") ("lb" nil "造")
	(";b" nil "芸") ("ob" nil "雄") ("pb" nil "春")
	("ng" nil "次") ("mg" nil "宅") (",g" nil "村")
	("hg" nil "円") ("jg" nil "四") ("kg" nil "十")
	("yg" nil "内") ("ug" nil "千") ("ig" nil "分")
	(".g" nil "古") ("/g" nil "袋") ("lg" nil "面")
	(";g" nil "教") ("og" nil "立") ("pg" nil "外")
	("zn" nil "負") ("xn" nil "認") ("cn" nil "愛")
	("vn" nil "着") ("bn" nil "消") ("an" nil "助")
	("sn" nil "性") ("dn" nil "話") ("fn" nil "語")
	("gn" nil "点") ("qn" nil "必") ("wn" nil "官")
	("en" nil "治") ("rn" nil "先") ("tn" nil "初")
	("zm" nil "失") ("xm" nil "想") ("cm" nil "流")
	("vm" nil "検") ("bm" nil "再") ("am" nil "写")
	("sm" nil "募") ("dm" nil "作") ("fm" nil "交")
	("gm" nil "重") ("qm" nil "講") ("wm" nil "府")
	("em" nil "談") ("rm" nil "協") ("tm" nil "反")
	("z," nil "起") ("x," nil "命") ("c," nil "説")
	("v," nil "婦") ("b," nil "言") ("n," nil "署")
	("m," nil "害") (",," nil "個") ("a," nil "権")
	("s," nil "選") ("d," nil "売") ("f," nil "店")
	("g," nil "男") ("h," nil "含") ("j," nil "聞")
	("k," nil "件") ("q," nil "使") ("w," nil "真")
	("e," nil "開") ("r," nil "決") ("t," nil "美")
	("y," nil "隊") ("u," nil "飛") ("i," nil "航")
	(".," nil "巻") ("/," nil "雨") ("l," nil "師")
	(";," nil "低") ("o," nil "寄") ("p," nil "満")
	("za" nil "奏") ("xa" nil "示") ("ca" nil "児")
	("va" nil "志") ("ba" nil "未") ("na" nil "研")
	("ma" nil "葉") (",a" nil "倉") ("aa" nil "深")
	("sa" nil "管") ("da" nil "勤") ("fa" nil "増")
	("ga" nil "習") ("ha" nil "藤") ("ja" nil "付")
	("ka" nil "経") ("qa" nil "念") ("wa" nil "右")
	("ea" nil "残") ("ra" nil "赤") ("ta" nil "形")
	("ya" nil "遇") ("ua" nil "井") ("ia" nil "島")
	(".a" nil "菱") ("/a" nil "浴") ("la" nil "正")
	(";a" nil "賞") ("oa" nil "士") ("pa" nil "坪")
	("zs" nil "医") ("xs" nil "単") ("cs" nil "貸")
	("vs" nil "追") ("bs" nil "挙") ("ns" nil "丸")
	("ms" nil "卒") (",s" nil "朝") ("as" nil "毎")
	("ss" nil "福") ("ds" nil "他") ("fs" nil "米")
	("gs" nil "利") ("hs" nil "代") ("js" nil "月")
	("ks" nil "田") ("qs" nil "税") ("ws" nil "質")
	("es" nil "団") ("rs" nil "参") ("ts" nil "基")
	("ys" nil "機") ("us" nil "野") ("is" nil "前")
	(".s" nil "農") ("/s" nil "億") ("ls" nil "後")
	(";s" nil "商") ("os" nil "百") ("ps" nil "接")
	("zd" nil "評") ("xd" nil "庭") ("cd" nil "改")
	("vd" nil "役") ("bd" nil "花") ("nd" nil "急")
	("md" nil "海") (",d" nil "市") ("ad" nil "約")
	("sd" nil "有") ("dd" nil "全") ("fd" nil "自")
	("gd" nil "住") ("hd" nil "東") ("jd" nil "二")
	("kd" nil "日") ("qd" nil "黒") ("wd" nil "資")
	("ed" nil "数") ("rd" nil "品") ("td" nil "座")
	("yd" nil "学") ("ud" nil "本") ("id" nil "大")
	(".d" nil "支") ("/d" nil "森") ("ld" nil "時")
	(";d" nil "不") ("od" nil "六") ("pd" nil "株")
	("zf" nil "討") ("xf" nil "具") ("cf" nil "防")
	("vf" nil "素") ("bf" nil "介") ("nf" nil "光")
	("mf" nil "郎") (",f" nil "文") ("af" nil "直")
	("sf" nil "送") ("df" nil "保") ("ff" nil "世")
	("gf" nil "現") ("hf" nil "新") ("jf" nil "年")
	("kf" nil "一") ("qf" nil "警") ("wf" nil "託")
	("ef" nil "公") ("rf" nil "細") ("tf" nil "費")
	("yf" nil "工") ("uf" nil "事") ("if" nil "中")
	(".f" nil "沢") ("/f" nil "馬") ("lf" nil "同")
	(";f" nil "歩") ("of" nil "九") ("pf" nil "午")
	("zh" nil "判") ("xh" nil "投") ("ch" nil "戦")
	("vh" nil "組") ("bh" nil "多") ("qh" nil "主")
	("zj" nil "策") ("xj" nil "備") ("cj" nil "当")
	("vj" nil "来") ("bj" nil "強") ("nj" nil "良")
	("mj" nil "様") (",j" nil "省") ("hj" nil "力")
	("jj" nil "験") ("kj" nil "間") ("yj" nil "勝")
	("uj" nil "氏") ("ij" nil "画") (".j" nil "型")
	("/j" nil "故") ("lj" nil "設") (";j" nil "号")
	("oj" nil "心") ("pj" nil "販")
	("zk" nil "若") ("xk" nil "記") ("ck" nil "委")
	("vk" nil "入") ("bk" nil "実") ("nk" nil "論")
	("mk" nil "値") (",k" nil "路") ("hk" nil "化")
	("jk" nil "下") ("kk" nil "回") ("yk" nil "歳")
	("uk" nil "度") ("ik" nil "校") (".k" nil "装")
	("/k" nil "働") ("lk" nil "歴") (";k" nil "係")
	("ok" nil "銀") ("pk" nil "転")
	("zq" nil "伸") ("xq" nil "羽") ("cq" nil "静")
	("vq" nil "財") ("bq" nil "始") ("nq" nil "河")
	("mq" nil "越") (",q" nil "統") ("aq" nil "悪")
	("sq" nil "病") ("dq" nil "早") ("fq" nil "糸")
	("gq" nil "試") ("hq" nil "松") ("jq" nil "安")
	("kq" nil "都") ("qq" nil "並") ("wq" nil "態")
	("eq" nil "両") ("rq" nil "乗") ("tq" nil "専")
	("yq" nil "興") ("uq" nil "口") ("iq" nil "洋")
	(".q" nil "秀") ("/q" nil "油") ("lq" nil "与")
	(";q" nil "清") ("oq" nil "船") ("pq" nil "久")
	("zw" nil "裏") ("xw" nil "短") ("cw" nil "何")
	("vw" nil "積") ("bw" nil "迎") ("nw" nil "元")
	("mw" nil "蔵") (",w" nil "県") ("aw" nil "根")
	("sw" nil "仕") ("dw" nil "無") ("fw" nil "案")
	("gw" nil "額") ("hw" nil "動") ("jw" nil "川")
	("kw" nil "給") ("qw" nil "伝") ("ww" nil "健")
	("ew" nil "待") ("rw" nil "白") ("tw" nil "港")
	("yw" nil "水") ("uw" nil "産") ("iw" nil "務")
	(".w" nil "築") ("/w" nil "角") ("lw" nil "木")
	(";w" nil "佐") ("ow" nil "駅") ("pw" nil "頭")
	("ze" nil "類") ("xe" nil "非") ("ce" nil "補")
	("ve" nil "軽") ("be" nil "率") ("ne" nil "崎")
	("me" nil "宿") (",e" nil "可") ("ae" nil "天")
	("se" nil "今") ("de" nil "各") ("fe" nil "関")
	("ge" nil "運") ("he" nil "高") ("je" nil "国")
	("ke" nil "三") ("qe" nil "青") ("we" nil "活")
	("ee" nil "結") ("re" nil "優") ("te" nil "最")
	("ye" nil "金") ("ue" nil "地") ("ie" nil "万")
	(".e" nil "室") ("/e" nil "渋") ("le" nil "八")
	(";e" nil "北") ("oe" nil "建") ("pe" nil "鉄")
	("zr" nil "復") ("xr" nil "遊") ("cr" nil "施")
	("vr" nil "帰") ("br" nil "便") ("nr" nil "半")
	("mr" nil "岡") (",r" nil "石") ("ar" nil "寮")
	("sr" nil "広") ("dr" nil "平") ("fr" nil "音")
	("gr" nil "計") ("hr" nil "山") ("jr" nil "電")
	("kr" nil "五") ("qr" nil "整") ("wr" nil "少")
	("er" nil "信") ("rr" nil "報") ("tr" nil "太")
	("yr" nil "町") ("ur" nil "七") ("ir" nil "京")
	(".r" nil "休") ("/r" nil "豊") ("lr" nil "小")
	(";r" nil "原") ("or" nil "理") ("pr" nil "営")
	("nt" nil "林") ("mt" nil "門") (",t" nil "格")
	("ht" nil "名") ("jt" nil "部") ("kt" nil "業")
	("yt" nil "第") ("ut" nil "和") ("it" nil "区")
	(".t" nil "吉") ("/t" nil "齢") ("lt" nil "問")
	(";t" nil "近") ("ot" nil "西") ("pt" nil "富")
	("zy" nil "落") ("xy" nil "情") ("cy" nil "私")
	("vy" nil "取") ("by" nil "別") ("ay" nil "書")
	("sy" nil "場") ("dy" nil "会") ("fy" nil "上")
	("gy" nil "通") ("qy" nil "食") ("wy" nil "持")
	("ey" nil "子") ("ry" nil "出") ("ty" nil "行")
	("zu" nil "好") ("xu" nil "館") ("cu" nil "調")
	("vu" nil "知") ("bu" nil "切") ("nu" nil "庁")
	("mu" nil "之") (",u" nil "旅") ("au" nil "目")
	("hu" nil "製") ("ju" nil "種") ("ku" nil "用")
	("yu" nil "割") ("uu" nil "及") ("iu" nil "楽")
	(".u" nil "仲") ("/u" nil "極") ("lu" nil "界")
	(";u" nil "容") ("ou" nil "園") ("pu" nil "終")
	("zi" nil "器") ("xi" nil "進") ("ci" nil "対")
	("vi" nil "要") ("bi" nil "意") ("ni" nil "然")
	("mi" nil "断") (",i" nil "険") ("hi" nil "連")
	("ji" nil "車") ("ki" nil "以") ("qi" nil "相")
	("yi" nil "民") ("ui" nil "表") ("ii" nil "夫")
	(".i" nil "構") ("/i" nil "郵") ("li" nil "完")
	(";i" nil "技") ("oi" nil "加") ("pi" nil "能")
	("z." nil "抜") ("x." nil "導") ("c." nil "席")
	("v." nil "録") ("b." nil "張") ("n." nil "華")
	("m." nil "量") (",." nil "視") ("a." nil "申")
	("s." nil "風") ("d." nil "打") ("f." nil "価")
	("g." nil "込") ("h." nil "比") ("j." nil "止")
	("k." nil "審") ("q." nil "左") ("w." nil "算")
	("e." nil "指") ("r." nil "向") ("t." nil "放")
	("y." nil "減") ("u." nil "陽") ("i." nil "払")
	(".." nil "彼") ("/." nil "才") ("l." nil "殺")
	(";." nil "例") ("o." nil "顔") ("p." nil "普")
	("z/" nil "違") ("x/" nil "声") ("c/" nil "提")
	("v/" nil "答") ("b/" nil "過") ("n/" nil "厚")
	("m/" nil "督") (",/" nil "練") ("a/" nil "確")
	("s/" nil "足") ("d/" nil "考") ("f/" nil "望")
	("g/" nil "規") ("h/" nil "準") ("j/" nil "難")
	("k/" nil "裁") ("q/" nil "展") ("w/" nil "得")
	("e/" nil "死") ("r/" nil "輸") ("t/" nil "味")
	("y/" nil "丁") ("u/" nil "善") ("i/" nil "材")
	("./" nil "況") ("//" nil "景") ("l/" nil "適")
	(";/" nil "図") ("o/" nil "差") ("p/" nil "洗")
	("zl" nil "任") ("xl" nil "引") ("cl" nil "党")
	("vl" nil "受") ("bl" nil "思") ("nl" nil "般")
	("ml" nil "編") (",l" nil "印") ("gl" nil "社")
	("hl" nil "夜") ("jl" nil "物") ("kl" nil "所")
	("wl" nil "見") ("yl" nil "紙") ("ul" nil "英")
	("il" nil "題") (".l" nil "敗") ("/l" nil "授")
	("ll" nil "際") (";l" nil "側") ("ol" nil "告")
	("pl" nil "勢") ("z;" nil "置") ("x;" nil "争")
	("c;" nil "義") ("v;" nil "査") ("b;" nil "派")
	("n;" nil "末") ("m;" nil "塁") (",;" nil "状")
	("a;" nil "歌") ("s;" nil "明") ("d;" nil "長")
	("f;" nil "方") ("g;" nil "政") ("h;" nil "位")
	("j;" nil "在") ("k;" nil "式") ("q;" nil "空")
	("w;" nil "線") ("e;" nil "合") ("r;" nil "家")
	("t;" nil "集") ("y;" nil "王") ("u;" nil "衛")
	("i;" nil "劇") (".;" nil "即") ("/;" nil "辺")
	("l;" nil "済") (";;" nil "究") ("o;" nil "親")
	("p;" nil "爆") ("zo" nil "読") ("xo" nil "求")
	("co" nil "演") ("vo" nil "術") ("bo" nil "身")
	("no" nil "字") ("mo" nil "養") (",o" nil "撃")
	("ao" nil "期") ("so" nil "発") ("do" nil "人")
	("fo" nil "員") ("go" nil "生") ("ho" nil "由")
	("jo" nil "局") ("ko" nil "体") ("qo" nil "解")
	("wo" nil "気") ("eo" nil "者") ("ro" nil "手")
	("to" nil "的") ("yo" nil "球") ("uo" nil "院")
	("io" nil "番") (".o" nil "司") ("/o" nil "居")
	("lo" nil "薬") (";o" nil "段") ("oo" nil "常")
	("po" nil "領") ("zp" nil "達") ("xp" nil "限")
	("cp" nil "応") ("vp" nil "買") ("bp" nil "感")
	("np" nil "閣") ("mp" nil "担") (",p" nil "将")
	("ap" nil "続") ("sp" nil "総") ("dp" nil "定")
	("fp" nil "女") ("gp" nil "成") ("hp" nil "級")
	("jp" nil "課") ("kp" nil "育") ("qp" nil "配")
	("wp" nil "予") ("ep" nil "議") ("rp" nil "特")
	("tp" nil "法") ("yp" nil "果") ("up" nil "等")
	("ip" nil "首") (".p" nil "械") ("/p" nil "護")
	("lp" nil "色") (";p" nil "巨") ("op" nil "毛")
	("pp" nil "券")
	("nnz" nil "鵬") ("mnz" nil "桓") (",nz" nil "讃")
	("hnz" nil "嵯") ("jnz" nil "遥") ("knz" nil "劾")
	("ynz" nil "鋸") ("unz" nil "裟") ("inz" nil "勃")
	(".nz" nil "兎") ("/nz" nil "叶") ("lnz" nil "鹸")
	(";nz" nil "詮") ("onz" nil "珊") ("pnz" nil "堆")
	("nmz" nil "潰") ("mmz" nil "硯") (",mz" nil "宍")
	("hmz" nil "蓉") ("jmz" nil "朔") ("kmz" nil "茜")
	("ymz" nil "鉱") ("umz" nil "雫") ("imz" nil "怨")
	(".mz" nil "諜") ("/mz" nil "脆") ("lmz" nil "謎")
	(";mz" nil "匙") ("omz" nil "肘") ("pmz" nil "俣")
	("nnx" nil "竪") ("mnx" nil "凧") (",nx" nil "茨")
	("hnx" nil "勾") ("jnx" nil "蛮") ("knx" nil "憤")
	("ynx" nil "峨") ("unx" nil "怜") ("inx" nil "茎")
	(".nx" nil "弛") ("/nx" nil "葛") ("lnx" nil "妖")
	(";nx" nil "隙") ("onx" nil "詣") ("pnx" nil "柑")
	("nmx" nil "歎") ("mmx" nil "檀") (",mx" nil "秦")
	("hmx" nil "拷") ("jmx" nil "哉") ("kmx" nil "俺")
	("ymx" nil "伶") ("umx" nil "鳳") ("imx" nil "磯")
	(".mx" nil "苛") ("/mx" nil "箕") ("lmx" nil "儒")
	(";mx" nil "挨") ("omx" nil "麓") ("pmx" nil "蛋")
	("nnc" nil "溢") ("mnc" nil "琵") (",nc" nil "藻")
	("hnc" nil "叱") ("jnc" nil "皿") ("knc" nil "励")
	("ync" nil "洲") ("unc" nil "虞") ("inc" nil "伺")
	(".nc" nil "櫛") ("/nc" nil "椀") ("lnc" nil "衷")
	(";nc" nil "嚇") ("onc" nil "釘") ("pnc" nil "樽")
	("nmc" nil "迂") ("mmc" nil "餅") (",mc" nil "藻")
	("hmc" nil "狼") ("jmc" nil "虐") ("kmc" nil "涙")
	("ymc" nil "爺") ("umc" nil "錘") ("imc" nil "軌")
	(".mc" nil "帖") ("/mc" nil "剥") ("lmc" nil "訟")
	(";mc" nil "肇") ("omc" nil "呆") ("pmc" nil "汲")
	("nnv" nil "腺") ("mnv" nil "蛙") (",nv" nil "禄")
	("hnv" nil "昆") ("jnv" nil "矛") ("knv" nil "惨")
	("ynv" nil "萎") ("unv" nil "尭") ("inv" nil "恨")
	(".nv" nil "迄") ("/nv" nil "碍") ("lnv" nil "襟")
	(";nv" nil "寅") ("onv" nil "麺") ("pnv" nil "稜")
	("nmv" nil "鮭") ("mmv" nil "蝿") (",mv" nil "孟")
	("hmv" nil "愁") ("jmv" nil "殴") ("kmv" nil "握")
	("ymv" nil "矯") ("umv" nil "藍") ("imv" nil "繭")
	(".mv" nil "戚") ("/mv" nil "醐") ("lmv" nil "租")
	(";mv" nil "斡") ("omv" nil "笹") ("pmv" nil "俄")
	("nnb" nil "鷲") ("mnb" nil "糞") (",nb" nil "姦")
	("hnb" nil "蕗") ("jnb" nil "冗") ("knb" nil "隈")
	("ynb" nil "萎") ("unb" nil "悌") ("inb" nil "醜")
	(".nb" nil "姐") ("/nb" nil "劫") ("lnb" nil "覇")
	(";nb" nil "堺") ("onb" nil "箔") ("pnb" nil "膝")
	("nmb" nil "杖") ("mmb" nil "屍") (",mb" nil "蔑")
	("hmb" nil "嘱") ("jmb" nil "惰") ("kmb" nil "蘭")
	("ymb" nil "蔦") ("umb" nil "蘇") ("imb" nil "呑")
	(".mb" nil "薮") ("/mb" nil "凌") ("lmb" nil "殉")
	(";mb" nil "廓") ("omb" nil "甫") ("pmb" nil "吠")
	("nna" nil "罫") ("mna" nil "屯") (",na" nil "喝")
	("hna" nil "旺") ("jna" nil "蝶") ("kna" nil "床")
	("yna" nil "嫡") ("una" nil "棟") ("ina" nil "輩")
	(".na" nil "諺") ("/na" nil "烏") ("lna" nil "庸")
	(";na" nil "拭") ("ona" nil "惣") ("pna" nil "梨")
	("nma" nil "酉") ("mma" nil "篠") (",ma" nil "盆")
	("hma" nil "苑") ("jma" nil "胴") ("kma" nil "菅")
	("yma" nil "緯") ("uma" nil "崖") ("ima" nil "幾")
	(".ma" nil "萌") ("/ma" nil "仔") ("lma" nil "尿")
	(";ma" nil "渥") ("oma" nil "蹴") ("pma" nil "腎")
	("nns" nil "岬") ("mns" nil "膜") (",ns" nil "坐")
	("hns" nil "隔") ("jns" nil "奉") ("kns" nil "浮")
	("yns" nil "婿") ("uns" nil "汗") ("ins" nil "沈")
	(".ns" nil "抹") ("/ns" nil "龍") ("lns" nil "憂")
	(";ns" nil "膨") ("ons" nil "堕") ("pns" nil "飢")
	("nms" nil "湧") ("mms" nil "鮎") (",ms" nil "閥")
	("hms" nil "揚") ("jms" nil "卓") ("kms" nil "載")
	("yms" nil "俗") ("ums" nil "妊") ("ims" nil "芦")
	(".ms" nil "蔭") ("/ms" nil "倭") ("lms" nil "懇")
	(";ms" nil "瞳") ("oms" nil "湿") ("pms" nil "壱")
	("nnd" nil "衿") ("mnd" nil "苗") (",nd" nil "諭")
	("hnd" nil "寛") ("jnd" nil "暮") ("knd" nil "片")
	("ynd" nil "巴") ("und" nil "趣") ("ind" nil "徴")
	(".nd" nil "淋") ("/nd" nil "餓") ("lnd" nil "律")
	(";nd" nil "紛") ("ond" nil "誉") ("pnd" nil "款")
	("nmd" nil "詐") ("mmd" nil "朴") (",md" nil "据")
	("hmd" nil "還") ("jmd" nil "悲") ("kmd" nil "危")
	("ymd" nil "鐘") ("umd" nil "忙") ("imd" nil "桂")
	(".md" nil "叙") ("/md" nil "駿") ("lmd" nil "躍")
	(";md" nil "獣") ("omd" nil "磨") ("pmd" nil "嘩")
	("nnf" nil "絢") ("mnf" nil "棚") (",nf" nil "殖")
	("hnf" nil "眠") ("jnf" nil "亀") ("knf" nil "弱")
	("ynf" nil "肺") ("unf" nil "泣") ("inf" nil "逮")
	(".nf" nil "丑") ("/nf" nil "爾") ("lnf" nil "襲")
	(";nf" nil "寒") ("onf" nil "貌") ("pnf" nil "邪")
	("nmf" nil "脈") ("mmf" nil "縛") (",mf" nil "繰")
	("hmf" nil "堅") ("jmf" nil "献") ("kmf" nil "乞")
	("ymf" nil "鷹") ("umf" nil "訂") ("imf" nil "弟")
	(".mf" nil "妃") ("/mf" nil "匁") ("lmf" nil "欠")
	(";mf" nil "溜") ("omf" nil "柔") ("pmf" nil "壷")
	("nng" nil "瑞") ("mng" nil "艶") (",ng" nil "粒")
	("hng" nil "奨") ("jng" nil "絵") ("kng" nil "勇")
	("yng" nil "敢") ("ung" nil "兆") ("ing" nil "忍")
	(".ng" nil "峻") ("/ng" nil "褒") ("lng" nil "釣")
	(";ng" nil "瓦") ("ong" nil "諾") ("png" nil "剖")
	("nmg" nil "狙") ("mmg" nil "戴") (",mg" nil "碁")
	("hmg" nil "悩") ("jmg" nil "童") ("kmg" nil "替")
	("ymg" nil "簿") ("umg" nil "欺") ("img" nil "棄")
	(".mg" nil "愉") ("/mg" nil "姑") ("lmg" nil "栃")
	(";mg" nil "浸") ("omg" nil "腐") ("pmg" nil "糎")
	("nnq" nil "勿") ("mnq" nil "阜") (",nq" nil "聡")
	("hnq" nil "斤") ("jnq" nil "憶") ("knq" nil "嘉")
	("ynq" nil "歪") ("unq" nil "噂") ("inq" nil "軸")
	(".nq" nil "烹") ("/nq" nil "縞") ("lnq" nil "妓")
	(";nq" nil "馨") ("onq" nil "喉") ("pnq" nil "飴")
	("nmq" nil "妾") ("mmq" nil "碇") (",mq" nil "酌")
	("hmq" nil "斜") ("jmq" nil "枕") ("kmq" nil "誕")
	("ymq" nil "股") ("umq" nil "薪") ("imq" nil "顕")
	(".mq" nil "牡") ("/mq" nil "獅") ("lmq" nil "猟")
	(";mq" nil "萩") ("omq" nil "倣") ("pmq" nil "痔")
	("nnw" nil "頓") ("mnw" nil "粍") (",nw" nil "稼")
	("hnw" nil "嶺") ("jnw" nil "卵") ("knw" nil "仮")
	("ynw" nil "謁") ("unw" nil "循") ("inw" nil "狭")
	(".nw" nil "苔") ("/nw" nil "娼") ("lnw" nil "屈")
	(";nw" nil "賠") ("onw" nil "嬉") ("pnw" nil "蛍")
	("nmw" nil "吊") ("mmw" nil "頻") (",mw" nil "蚊")
	("hmw" nil "炎") ("jmw" nil "庶") ("kmw" nil "序")
	("ymw" nil "裸") ("umw" nil "坑") ("imw" nil "遭")
	(".mw" nil "允") ("/mw" nil "溺") ("lmw" nil "帽")
	(";mw" nil "爵") ("omw" nil "賭") ("pmw" nil "朋")
	("nne" nil "亨") ("mne" nil "践") (",ne" nil "暇")
	("hne" nil "縦") ("jne" nil "騒") ("kne" nil "辞")
	("yne" nil "隅") ("une" nil "往") ("ine" nil "銃")
	(".ne" nil "渇") ("/ne" nil "琢") ("lne" nil "壁")
	(";ne" nil "酔") ("one" nil "泡") ("pne" nil "錯")
	("nme" nil "燥") ("mme" nil "癖") (",me" nil "腹")
	("hme" nil "淡") ("jme" nil "誇") ("kme" nil "被")
	("yme" nil "棋") ("ume" nil "圏") ("ime" nil "衝")
	(".me" nil "云") ("/me" nil "畿") ("lme" nil "貫")
	(";me" nil "劣") ("ome" nil "岐") ("pme" nil "蒼")
	("nnr" nil "彬") ("mnr" nil "狗") (",nr" nil "恭")
	("hnr" nil "涼") ("jnr" nil "肌") ("knr" nil "牧")
	("ynr" nil "扉") ("unr" nil "騰") ("inr" nil "砲")
	(".nr" nil "惇") ("/nr" nil "枠") ("lnr" nil "炊")
	(";nr" nil "唆") ("onr" nil "窟") ("pnr" nil "帆")
	("nmr" nil "蚕") ("mmr" nil "鈎") (",mr" nil "衡")
	("hmr" nil "佳") ("jmr" nil "裳") ("kmr" nil "縮")
	("ymr" nil "漢") ("umr" nil "幻") ("imr" nil "妹")
	(".mr" nil "箇") ("/mr" nil "塵") ("lmr" nil "嵐")
	(";mr" nil "噴") ("omr" nil "縁") ("pmr" nil "廿")
	("nnt" nil "畏") ("mnt" nil "赦") (",nt" nil "崩")
	("hnt" nil "奮") ("jnt" nil "蓄") ("knt" nil "勧")
	("ynt" nil "膳") ("unt" nil "咲") ("int" nil "拒")
	(".nt" nil "汎") ("/nt" nil "牝") ("lnt" nil "蓮")
	(";nt" nil "沸") ("ont" nil "郭") ("pnt" nil "撒")
	("nmt" nil "繍") ("mmt" nil "鯉") (",mt" nil "拙")
	("hmt" nil "挑") ("jmt" nil "粛") ("kmt" nil "吹")
	("ymt" nil "紫") ("umt" nil "芽") ("imt" nil "搭")
	(".mt" nil "釦") ("/mt" nil "瓜") ("lmt" nil "貞")
	(";mt" nil "盲") ("omt" nil "蛇") ("pmt" nil "肢")
	("zgn" nil "芥") ("xgn" nil "把") ("cgn" nil "謄")
	("vgn" nil "漆") ("bgn" nil "楓") ("agn" nil "淑")
	("sgn" nil "麦") ("dgn" nil "箱") ("fgn" nil "鴨")
	("ggn" nil "慢") ("qgn" nil "喰") ("wgn" nil "窒")
	("egn" nil "侵") ("rgn" nil "墓") ("tgn" nil "粗")
	("zgm" nil "佑") ("xgm" nil "欽") ("cgm" nil "透")
	("vgm" nil "囚") ("bgm" nil "紘") ("agm" nil "隻")
	("sgm" nil "俳") ("dgm" nil "存") ("fgm" nil "菓")
	("ggm" nil "弦") ("qgm" nil "符") ("wgm" nil "廊")
	("egm" nil "黄") ("rgm" nil "脚") ("tgm" nil "慰")
	("zg," nil "鍾") ("xg," nil "剃") ("cg," nil "麗")
	("vg," nil "拳") ("bg," nil "帥") ("ag," nil "奪")
	("sg," nil "露") ("dg," nil "乳") ("fg," nil "看")
	("gg," nil "腰") ("qg," nil "怖") ("wg," nil "埋")
	("eg," nil "綱") ("rg," nil "贈") ("tg," nil "獲")
	("zgh" nil "雀") ("xgh" nil "墜") ("cgh" nil "銭")
	("vgh" nil "帳") ("bgh" nil "桐") ("agh" nil "倒")
	("sgh" nil "笑") ("dgh" nil "婚") ("fgh" nil "絶")
	("ggh" nil "障") ("qgh" nil "尚") ("wgh" nil "憲")
	("egh" nil "肉") ("rgh" nil "衣") ("tgh" nil "繁")
	("zgj" nil "勘") ("xgj" nil "翌") ("cgj" nil "里")
	("vgj" nil "掃") ("bgj" nil "唯") ("agj" nil "維")
	("sgj" nil "盤") ("dgj" nil "幹") ("fgj" nil "舎")
	("ggj" nil "瀬") ("qgj" nil "詩") ("wgj" nil "沖")
	("egj" nil "丘") ("rgj" nil "散") ("tgj" nil "願")
	("zgk" nil "距") ("xgk" nil "坊") ("cgk" nil "渉")
	("vgk" nil "簡") ("bgk" nil "到") ("agk" nil "拡")
	("sgk" nil "降") ("dgk" nil "供") ("fgk" nil "圧")
	("ggk" nil "繊") ("qgk" nil "快") ("wgk" nil "麻")
	("egk" nil "杉") ("rgk" nil "捕") ("tgk" nil "貿")
	("zgy" nil "培") ("xgy" nil "堪") ("cgy" nil "浩")
	("vgy" nil "液") ("bgy" nil "奴") ("agy" nil "納")
	("sgy" nil "郷") ("dgy" nil "奥") ("fgy" nil "又")
	("ggy" nil "筆") ("qgy" nil "哲") ("wgy" nil "弾")
	("egy" nil "炭") ("rgy" nil "稲") ("tgy" nil "為")
	("zgu" nil "貢") ("xgu" nil "肝") ("cgu" nil "俊")
	("vgu" nil "契") ("bgu" nil "恩") ("agu" nil "痛")
	("sgu" nil "順") ("dgu" nil "周") ("fgu" nil "荒")
	("ggu" nil "錠") ("qgu" nil "錦") ("wgu" nil "罪")
	("egu" nil "績") ("rgu" nil "昼") ("tgu" nil "熊")
	("zgi" nil "醸") ("xgi" nil "鋳") ("cgi" nil "雲")
	("vgi" nil "也") ("bgi" nil "抵") ("agi" nil "牛")
	("sgi" nil "織") ("dgi" nil "夏") ("fgi" nil "援")
	("ggi" nil "盟") ("qgi" nil "蒲") ("wgi" nil "候")
	("egi" nil "盛") ("rgi" nil "激") ("tgi" nil "批")
	("zg." nil "拶") ("xg." nil "釧") ("cg." nil "耗")
	("vg." nil "侮") ("bg." nil "幌") ("ag." nil "滋")
	("sg." nil "壇") ("dg." nil "亡") ("fg." nil "敵")
	("gg." nil "凡") ("qg." nil "餌") ("wg." nil "穏")
	("eg." nil "胃") ("rg." nil "聖") ("tg." nil "僕")
	("zg/" nil "樋") ("xg/" nil "槍") ("cg/" nil "凹")
	("vg/" nil "祐") ("bg/" nil "燐") ("ag/" nil "愚")
	("sg/" nil "倫") ("dg/" nil "控") ("fg/" nil "鉛")
	("gg/" nil "懲") ("qg/" nil "隼") ("wg/" nil "傘")
	("eg/" nil "唄") ("rg/" nil "罰") ("tg/" nil "臥")
	("zgl" nil "磁") ("xgl" nil "召") ("cgl" nil "徹")
	("vgl" nil "汚") ("bgl" nil "喪") ("agl" nil "禁")
	("sgl" nil "底") ("dgl" nil "節") ("fgl" nil "焼")
	("ggl" nil "移") ("qgl" nil "骨") ("wgl" nil "荘")
	("egl" nil "帯") ("rgl" nil "捜") ("tgl" nil "逆")
	("zg;" nil "陪") ("xg;" nil "肖") ("cg;" nil "艦")
	("vg;" nil "概") ("bg;" nil "疎") ("ag;" nil "虫")
	("sg;" nil "菜") ("dg;" nil "異") ("fg;" nil "努")
	("gg;" nil "困") ("qg;" nil "靴") ("wg;" nil "奇")
	("eg;" nil "紅") ("rg;" nil "窓") ("tg;" nil "掛")
	("zgo" nil "丞") ("xgo" nil "瓶") ("cgo" nil "啓")
	("vgo" nil "恒") ("bgo" nil "尽") ("ago" nil "弥")
	("sgo" nil "承") ("dgo" nil "域") ("fgo" nil "君")
	("ggo" nil "幕") ("qgo" nil "誘") ("wgo" nil "剤")
	("ego" nil "弁") ("rgo" nil "歯") ("tgo" nil "祥")
	("zgp" nil "詔") ("xgp" nil "寧") ("cgp" nil "斗")
	("vgp" nil "媒") ("bgp" nil "詠") ("agp" nil "添")
	("sgp" nil "却") ("dgp" nil "幡") ("fgp" nil "震")
	("ggp" nil "灯") ("qgp" nil "匠") ("wgp" nil "淵")
	("egp" nil "宗") ("rgp" nil "鬼") ("tgp" nil "慣")
	("nhz" nil "卦") ("mhz" nil "羅") (",hz" nil "殻")
	("hhz" nil "胎") ("jhz" nil "尊") ("khz" nil "零")
	("yhz" nil "迅") ("uhz" nil "牲") ("ihz" nil "抑")
	(".hz" nil "賎") ("/hz" nil "醍") ("lhz" nil "赴")
	(";hz" nil "漸") ("ohz" nil "弔") ("phz" nil "拐")
	("nhx" nil "玩") ("mhx" nil "伐") (",hx" nil "喧")
	("hhx" nil "梶") ("jhx" nil "至") ("khx" nil "宙")
	("yhx" nil "偉") ("uhx" nil "拓") ("ihx" nil "亭")
	(".hx" nil "芯") ("/hx" nil "銚") ("lhx" nil "糧")
	(";hx" nil "酢") ("ohx" nil "涯") ("phx" nil "幣")
	("nhc" nil "絞") ("mhc" nil "痢") (",hc" nil "壊")
	("hhc" nil "脂") ("jhc" nil "儀") ("khc" nil "喫")
	("yhc" nil "垣") ("uhc" nil "排") ("ihc" nil "逃")
	(".hc" nil "頑") ("/hc" nil "且") ("lhc" nil "謝")
	(";hc" nil "硬") ("ohc" nil "孫") ("phc" nil "閑")
	("nhv" nil "塀") ("mhv" nil "翻") (",hv" nil "拍")
	("hhv" nil "鏡") ("jhv" nil "飲") ("khv" nil "欧")
	("yhv" nil "遂") ("uhv" nil "潮") ("ihv" nil "混")
	(".hv" nil "矩") ("/hv" nil "敦") ("lhv" nil "穴")
	(";hv" nil "豚") ("ohv" nil "征") ("phv" nil "妨")
	("nhb" nil "塀") ("mhb" nil "陵") (",hb" nil "畔")
	("hhb" nil "抽") ("jhb" nil "賦") ("khb" nil "致")
	("yhb" nil "炉") ("uhb" nil "驚") ("ihb" nil "雅")
	(".hb" nil "鉢") ("/hb" nil "咽") ("lhb" nil "姉")
	(";hb" nil "丈") ("ohb" nil "僧") ("phb" nil "机")
	("nha" nil "偶") ("mha" nil "刃") (",ha" nil "扶")
	("hha" nil "兼") ("jha" nil "因") ("kha" nil "筋")
	("yha" nil "淳") ("uha" nil "阿") ("iha" nil "刷")
	(".ha" nil "吏") ("/ha" nil "或") ("lha" nil "湾")
	(";ha" nil "預") ("oha" nil "棒") ("pha" nil "触")
	("nhs" nil "阻") ("mhs" nil "呉") (",hs" nil "囲")
	("hhs" nil "飯") ("jhs" nil "象") ("khs" nil "系")
	("yhs" nil "慮") ("uhs" nil "乱") ("ihs" nil "房")
	(".hs" nil "穀") ("/hs" nil "謀") ("lhs" nil "傷")
	(";hs" nil "柳") ("ohs" nil "塗") ("phs" nil "措")
	("nhd" nil "泳") ("mhd" nil "包") (",hd" nil "端")
	("hhd" nil "責") ("jhd" nil "康") ("khd" nil "針")
	("yhd" nil "紀") ("uhd" nil "賀") ("ihd" nil "突")
	(".hd" nil "肥") ("/hd" nil "己") ("lhd" nil "締")
	(";hd" nil "債") ("ohd" nil "互") ("phd" nil "著")
	("nhf" nil "籍") ("mhf" nil "息") (",hf" nil "季")
	("hhf" nil "依") ("jhf" nil "紡") ("khf" nil "徒")
	("yhf" nil "輪") ("uhf" nil "純") ("ihf" nil "糖")
	(".hf" nil "斎") ("/hf" nil "巳") ("lhf" nil "換")
	(";hf" nil "汽") ("ohf" nil "竜") ("phf" nil "絹")
	("nhg" nil "撲") ("mhg" nil "踏") (",hg" nil "荻")
	("hhg" nil "盗") ("jhg" nil "識") ("khg" nil "喜")
	("yhg" nil "老") ("uhg" nil "奈") ("ihg" nil "干")
	(".hg" nil "陳") ("/hg" nil "巧") ("lhg" nil "犯")
	(";hg" nil "塩") ("ohg" nil "夢") ("phg" nil "複")
	("nhq" nil "叉") ("mhq" nil "掌") (",hq" nil "呂")
	("hhq" nil "寝") ("jhq" nil "扱") ("khq" nil "豪")
	("yhq" nil "函") ("uhq" nil "孝") ("ihq" nil "陣")
	(".hq" nil "馳") ("/hq" nil "褐") ("lhq" nil "眼")
	(";hq" nil "窯") ("ohq" nil "緩") ("phq" nil "妥")
	("nhw" nil "擁") ("mhw" nil "捨") (",hw" nil "殿")
	("hhw" nil "就") ("jhw" nil "父") ("khw" nil "謡")
	("yhw" nil "殊") ("uhw" nil "償") ("ihw" nil "余")
	(".hw" nil "虜") ("/hw" nil "堤") ("lhw" nil "災")
	(";hw" nil "葬") ("ohw" nil "封") ("phw" nil "促")
	("nhe" nil "撮") ("mhe" nil "昌") (",he" nil "鶴")
	("hhe" nil "須") ("jhe" nil "布") ("khe" nil "舞")
	("yhe" nil "弘") ("uhe" nil "延") ("ihe" nil "彦")
	(".he" nil "珍") ("/he" nil "旋") ("lhe" nil "破")
	(";he" nil "忠") ("ohe" nil "樹") ("phe" nil "鮮")
	("nhr" nil "陛") ("mhr" nil "訓") (",hr" nil "燃")
	("hhr" nil "操") ("jhr" nil "温") ("khr" nil "密")
	("yhr" nil "巣") ("uhr" nil "標") ("ihr" nil "押")
	(".hr" nil "暦") ("/hr" nil "偵") ("lhr" nil "舗")
	(";hr" nil "遺") ("ohr" nil "梅") ("phr" nil "冬")
	("nht" nil "其") ("mht" nil "穂") (",ht" nil "診")
	("hht" nil "招") ("jht" nil "血") ("kht" nil "遠")
	("yht" nil "摩") ("uht" nil "旧") ("iht" nil "核")
	(".ht" nil "蒸") ("/ht" nil "篤") ("lht" nil "豆")
	(";ht" nil "礎") ("oht" nil "了") ("pht" nil "裕")
	("zvn" nil "遡") ("xvn" nil "峯") ("cvn" nil "榊")
	("vvn" nil "撫") ("bvn" nil "慾") ("avn" nil "豹")
	("svn" nil "漏") ("dvn" nil "摂") ("fvn" nil "煩")
	("gvn" nil "桶") ("qvn" nil "肋") ("wvn" nil "碧")
	("evn" nil "銑") ("rvn" nil "狐") ("tvn" nil "脹")
	("zbn" nil "堰") ("xbn" nil "蕉") ("cbn" nil "厭")
	("vbn" nil "采") ("bbn" nil "膿") ("abn" nil "柵")
	("sbn" nil "虹") ("dbn" nil "椅") ("fbn" nil "尺")
	("gbn" nil "芙") ("qbn" nil "灼") ("wbn" nil "叩")
	("ebn" nil "頬") ("rbn" nil "暢") ("tbn" nil "冥")
	("zvm" nil "茸") ("xvm" nil "雁") ("cvm" nil "妄")
	("vvm" nil "芭") ("bvm" nil "埼") ("avm" nil "牙")
	("svm" nil "陥") ("dvm" nil "宛") ("fvm" nil "迭")
	("gvm" nil "累") ("qvm" nil "燕") ("wvm" nil "搾")
	("evm" nil "菩") ("rvm" nil "濫") ("tvm" nil "喬")
	("zbm" nil "屠") ("xbm" nil "蓬") ("cbm" nil "遼")
	("vbm" nil "楚") ("bbm" nil "伽") ("abm" nil "耶")
	("sbm" nil "欣") ("dbm" nil "偽") ("fbm" nil "廉")
	("gbm" nil "溝") ("qbm" nil "謬") ("wbm" nil "賑")
	("ebm" nil "丙") ("rbm" nil "匡") ("tbm" nil "煎")
	("zv," nil "悶") ("xv," nil "閃") ("cv," nil "勺")
	("vv," nil "魁") ("bv," nil "蜜") ("av," nil "弐")
	("sv," nil "架") ("dv," nil "雇") ("fv," nil "窮")
	("gv," nil "晶") ("qv," nil "灸") ("wv," nil "濡")
	("ev," nil "魂") ("rv," nil "穣") ("tv," nil "姻")
	("zb," nil "酋") ("xb," nil "噌") ("cb," nil "塑")
	("vb," nil "牢") ("bb," nil "尤") ("ab," nil "梢")
	("sb," nil "頒") ("db," nil "升") ("fb," nil "刀")
	("gb," nil "蹟") ("qb," nil "夷") ("wb," nil "淫")
	("eb," nil "廻") ("rb," nil "舌") ("tb," nil "柏")
	("zvh" nil "梱") ("xvh" nil "閲") ("cvh" nil "釜")
	("vvh" nil "凝") ("bvh" nil "灰") ("avh" nil "滑")
	("svh" nil "詳") ("dvh" nil "駐") ("fvh" nil "摘")
	("gvh" nil "濃") ("qvh" nil "繕") ("wvh" nil "似")
	("evh" nil "泰") ("rvh" nil "搬") ("tvh" nil "迷")
	("zbh" nil "串") ("xbh" nil "紗") ("cbh" nil "虚")
	("vbh" nil "穫") ("bbh" nil "晋") ("abh" nil "騎")
	("sbh" nil "稿") ("dbh" nil "刑") ("fbh" nil "宏")
	("gbh" nil "笠") ("qbh" nil "葦") ("wbh" nil "某")
	("ebh" nil "冊") ("rbh" nil "紋") ("tbh" nil "吐")
	("zvj" nil "稔") ("xvj" nil "附") ("cvj" nil "孤")
	("vvj" nil "厄") ("bvj" nil "酬") ("avj" nil "誰")
	("svj" nil "戻") ("dvj" nil "礼") ("fvj" nil "犬")
	("gvj" nil "暖") ("qvj" nil "雰") ("wvj" nil "辻")
	("evj" nil "聴") ("rvj" nil "祉") ("tvj" nil "琴")
	("zbj" nil "禎") ("xbj" nil "沙") ("cbj" nil "撤")
	("vbj" nil "徐") ("bbj" nil "梓") ("abj" nil "猛")
	("sbj" nil "彰") ("dbj" nil "揮") ("fbj" nil "傾")
	("gbj" nil "銅") ("qbj" nil "芋") ("wbj" nil "庄")
	("ebj" nil "晩") ("rbj" nil "潜") ("tbj" nil "乏")
	("zvk" nil "汐") ("xvk" nil "径") ("cvk" nil "称")
	("vvk" nil "憎") ("bvk" nil "狩") ("avk" nil "抱")
	("svk" nil "更") ("dvk" nil "倍") ("fvk" nil "鎌")
	("gvk" nil "珠") ("qvk" nil "胞") ("wvk" nil "覧")
	("evk" nil "乃") ("rvk" nil "瞬") ("tvk" nil "縫")
	("zbk" nil "渦") ("xbk" nil "僅") ("cbk" nil "頁")
	("vbk" nil "李") ("bbk" nil "婆") ("abk" nil "弊")
	("sbk" nil "熟") ("dbk" nil "影") ("fbk" nil "欲")
	("gbk" nil "胸") ("qbk" nil "鍋") ("wbk" nil "諮")
	("ebk" nil "射") ("rbk" nil "臓") ("tbk" nil "准")
	("zvy" nil "砦") ("xvy" nil "闇") ("cvy" nil "鍵")
	("vvy" nil "渓") ("bvy" nil "抄") ("avy" nil "尉")
	("svy" nil "軟") ("dvy" nil "辰") ("fvy" nil "祖")
	("gvy" nil "彫") ("qvy" nil "桟") ("wvy" nil "頃")
	("evy" nil "篇") ("rvy" nil "猿") ("tvy" nil "析")
	("zby" nil "舷") ("xby" nil "柿") ("cby" nil "鈍")
	("vby" nil "醤") ("bby" nil "柴") ("aby" nil "盾")
	("sby" nil "猫") ("dby" nil "漫") ("fby" nil "敬")
	("gby" nil "唐") ("qby" nil "璽") ("wby" nil "尼")
	("eby" nil "拝") ("rby" nil "弓") ("tby" nil "匂")
	("zvu" nil "杜") ("xvu" nil "綴") ("cvu" nil "購")
	("vvu" nil "裾") ("bvu" nil "介") ("avu" nil "賜")
	("svu" nil "犠") ("dvu" nil "隆") ("fvu" nil "沿")
	("gvu" nil "魔") ("qvu" nil "訊") ("wvu" nil "漂")
	("evu" nil "畜") ("rvu" nil "没") ("tvu" nil "裂")
	("zbu" nil "瞭") ("xbu" nil "塔") ("cbu" nil "峠")
	("vbu" nil "剛") ("bbu" nil "罷") ("abu" nil "如")
	("sbu" nil "耕") ("dbu" nil "緑") ("fbu" nil "腕")
	("gbu" nil "脇") ("qbu" nil "葵") ("wbu" nil "忌")
	("ebu" nil "滞") ("rbu" nil "烈") ("tbu" nil "賓")
	("zvi" nil "槙") ("xvi" nil "娯") ("cvi" nil "伯")
	("vvi" nil "遍") ("bvi" nil "享") ("avi" nil "袖")
	("svi" nil "粧") ("dvi" nil "頼") ("fvi" nil "峰")
	("gvi" nil "祝") ("qvi" nil "嫌") ("wvi" nil "班")
	("evi" nil "墨") ("rvi" nil "披") ("tvi" nil "舶")
	("zbi" nil "槙") ("xbi" nil "瑛") ("cbi" nil "貼")
	("vbi" nil "播") ("bbi" nil "毅") ("abi" nil "袖")
	("sbi" nil "酵") ("dbi" nil "迫") ("fbi" nil "娘")
	("gbi" nil "貝") ("qbi" nil "悼") ("wbi" nil "滴")
	("ebi" nil "菌") ("rbi" nil "伏") ("tbi" nil "筈")
	("zv." nil "蕪") ("xv." nil "腿") ("cv." nil "湘")
	("vv." nil "卿") ("bv." nil "鎚") ("av." nil "洛")
	("sv." nil "馴") ("dv." nil "后") ("fv." nil "洪")
	("gv." nil "宰") ("qv." nil "麹") ("wv." nil "昏")
	("ev." nil "惟") ("rv." nil "痕") ("tv." nil "諒")
	("zb." nil "醒") ("xb." nil "苅") ("cb." nil "淀")
	("vb." nil "槻") ("bb." nil "耽") ("ab." nil "叡")
	("sb." nil "唾") ("db." nil "礁") ("fb." nil "雌")
	("gb." nil "諏") ("qb." nil "綻") ("wb." nil "碓")
	("eb." nil "圭") ("rb." nil "亮") ("tb." nil "牌")
	("zv/" nil "袴") ("xv/" nil "壬") ("cv/" nil "蛾")
	("vv/" nil "曾") ("bv/" nil "汀") ("av/" nil "祇")
	("sv/" nil "亘") ("dv/" nil "駈") ("fv/" nil "臆")
	("gv/" nil "癒") ("qv/" nil "倦") ("wv/" nil "灘")
	("ev/" nil "鞍") ("rv/" nil "凪") ("tv/" nil "舘")
	("zb/" nil "鞭") ("xb/" nil "屑") ("cb/" nil "狽")
	("vb/" nil "竿") ("bb/" nil "饗") ("ab/" nil "樫")
	("sb/" nil "奄") ("db/" nil "卯") ("fb/" nil "靖")
	("gb/" nil "迦") ("qb/" nil "弄") ("wb/" nil "捺")
	("eb/" nil "宋") ("rb/" nil "諦") ("tb/" nil "贋")
	("zvl" nil "凱") ("xvl" nil "喚") ("cvl" nil "溶")
	("vvl" nil "旭") ("bvl" nil "隷") ("avl" nil "拾")
	("svl" nil "薦") ("dvl" nil "兄") ("fvl" nil "陰")
	("gvl" nil "杯") ("qvl" nil "杏") ("wvl" nil "汁")
	("evl" nil "戒") ("rvl" nil "宵") ("tvl" nil "雷")
	("zbl" nil "琶") ("xbl" nil "亦") ("cbl" nil "睡")
	("vbl" nil "辱") ("bbl" nil "麿") ("abl" nil "衰")
	("sbl" nil "浄") ("dbl" nil "刻") ("fbl" nil "誤")
	("gbl" nil "脅") ("qbl" nil "胤") ("wbl" nil "胡")
	("ebl" nil "髪") ("rbl" nil "駆") ("tbl" nil "姓")
	("zv;" nil "潅") ("xv;" nil "俸") ("cv;" nil "腫")
	("vv;" nil "庵") ("bv;" nil "凸") ("av;" nil "蓋")
	("sv;" nil "俵") ("dv;" nil "厘") ("fv;" nil "筒")
	("gv;" nil "叫") ("qv;" nil "呪") ("wv;" nil "幽")
	("ev;" nil "羊") ("rv;" nil "棺") ("tv;" nil "轄")
	("zb;" nil "註") ("xb;" nil "汰") ("cb;" nil "稽")
	("vb;" nil "痘") ("bb;" nil "牟") ("ab;" nil "墳")
	("sb;" nil "辛") ("db;" nil "索") ("fb;" nil "廷")
	("gb;" nil "濁") ("qb;" nil "咳") ("wb;" nil "嵩")
	("eb;" nil "揺") ("rb;" nil "憾") ("tb;" nil "只")
	("zvo" nil "髭") ("xvo" nil "郁") ("cvo" nil "逢")
	("vvo" nil "緋") ("bvo" nil "貰") ("avo" nil "寂")
	("svo" nil "霊") ("dvo" nil "桑") ("fvo" nil "勲")
	("gvo" nil "携") ("qvo" nil "輔") ("wvo" nil "匿")
	("evo" nil "潔") ("rvo" nil "肪") ("tvo" nil "括")
	("zbo" nil "楯") ("xbo" nil "粟") ("cbo" nil "缶")
	("vbo" nil "嘘") ("bbo" nil "榎") ("abo" nil "巾")
	("sbo" nil "剰") ("dbo" nil "芳") ("fbo" nil "鍛")
	("gbo" nil "怠") ("qbo" nil "睦") ("wbo" nil "恰")
	("ebo" nil "賄") ("rbo" nil "鯨") ("tbo" nil "寡")
	("zvp" nil "蒙") ("xvp" nil "箸") ("cvp" nil "遮")
	("vvp" nil "舵") ("bvp" nil "嶋") ("avp" nil "楠")
	("svp" nil "濯") ("dvp" nil "悟") ("fvp" nil "峡")
	("gvp" nil "斐") ("qvp" nil "苫") ("wvp" nil "殆")
	("evp" nil "暫") ("rvp" nil "壌") ("tvp" nil "疫")
	("zbp" nil "椎") ("xbp" nil "鼠") ("cbp" nil "栓")
	("vbp" nil "冨") ("bbp" nil "乎") ("abp" nil "渚")
	("sbp" nil "慌") ("dbp" nil "曽") ("fbp" nil "洞")
	("gbp" nil "翁") ("qbp" nil "樺") ("wbp" nil "甥")
	("ebp" nil "漬") ("rbp" nil "凄") ("tbp" nil "癌")
	("ztn" nil "兜") ("xtn" nil "蟻") ("ctn" nil "紐")
	("vtn" nil "朕") ("btn" nil "斧") ("atn" nil "唇")
	("stn" nil "嬢") ("dtn" nil "網") ("ftn" nil "虎")
	("gtn" nil "惜") ("qtn" nil "奔") ("wtn" nil "痴")
	("etn" nil "威") ("rtn" nil "耐") ("ttn" nil "侍")
	("ztm" nil "倶") ("xtm" nil "羨") ("ctm" nil "擦")
	("vtm" nil "挟") ("btm" nil "椿") ("atm" nil "漠")
	("stm" nil "鎖") ("dtm" nil "畑") ("ftm" nil "浪")
	("gtm" nil "黙") ("qtm" nil "娠") ("wtm" nil "揃")
	("etm" nil "患") ("rtm" nil "句") ("ttm" nil "笛")
	("zt," nil "尖") ("xt," nil "爪") ("ct," nil "酪")
	("vt," nil "昂") ("bt," nil "盃") ("at," nil "禅")
	("st," nil "郊") ("dt," nil "皮") ("ft," nil "鳴")
	("gt," nil "微") ("qt," nil "胆") ("wt," nil "貧")
	("et," nil "略") ("rt," nil "克") ("tt," nil "謹")
	("zth" nil "勅") ("xth" nil "酷") ("cth" nil "閉")
	("vth" nil "煮") ("bth" nil "糾") ("ath" nil "翼")
	("sth" nil "占") ("dth" nil "恵") ("fth" nil "均")
	("gth" nil "列") ("qth" nil "範") ("wth" nil "紹")
	("eth" nil "走") ("rth" nil "香") ("tth" nil "層")
	("ztj" nil "霜") ("xtj" nil "隠") ("ctj" nil "旗")
	("vtj" nil "泊") ("btj" nil "嗣") ("atj" nil "折")
	("stj" nil "誌") ("dtj" nil "岸") ("ftj" nil "譲")
	("gtj" nil "魚") ("qtj" nil "救") ("wtj" nil "臨")
	("etj" nil "妻") ("rtj" nil "処") ("ttj" nil "留")
	("ztk" nil "槽") ("xtk" nil "賢") ("ctk" nil "廃")
	("vtk" nil "甘") ("btk" nil "朱") ("atk" nil "恋")
	("stk" nil "療") ("dtk" nil "客") ("ftk" nil "除")
	("gtk" nil "典") ("qtk" nil "継") ("wtk" nil "砂")
	("etk" nil "革") ("rtk" nil "請") ("ttk" nil "亜")
	("zty" nil "亥") ("xty" nil "朽") ("cty" nil "懸")
	("vty" nil "臭") ("bty" nil "眉") ("aty" nil "縄")
	("sty" nil "探") ("dty" nil "歓") ("fty" nil "催")
	("gty" nil "需") ("qty" nil "智") ("wty" nil "誠")
	("ety" nil "訳") ("rty" nil "源") ("tty" nil "恐")
	("ztu" nil "髄") ("xtu" nil "骸") ("ctu" nil "掘")
	("vtu" nil "彩") ("btu" nil "泌") ("atu" nil "皆")
	("stu" nil "矢") ("dtu" nil "副") ("ftu" nil "幅")
	("gtu" nil "遅") ("qtu" nil "忘") ("wtu" nil "覚")
	("etu" nil "秘") ("rtu" nil "雪") ("ttu" nil "紳")
	("zti" nil "宜") ("xti" nil "誓") ("cti" nil "硫")
	("vti" nil "謙") ("bti" nil "刈") ("ati" nil "滝")
	("sti" nil "鹿") ("dti" nil "固") ("fti" nil "堀")
	("gti" nil "創") ("qti" nil "魅") ("wti" nil "述")
	("eti" nil "令") ("rti" nil "測") ("tti" nil "朗")
	("zt." nil "茅") ("xt." nil "脊") ("ct." nil "慧")
	("vt." nil "瑠") ("bt." nil "禿") ("at." nil "鳩")
	("st." nil "薫") ("dt." nil "舟") ("ft." nil "妙")
	("gt." nil "祈") ("qt." nil "飽") ("wt." nil "楼")
	("et." nil "是") ("rt." nil "択") ("tt." nil "凶")
	("zt/" nil "漕") ("xt/" nil "稀") ("ct/" nil "糊")
	("vt/" nil "粕") ("bt/" nil "逗") ("at/" nil "遵")
	("st/" nil "墾") ("dt/" nil "柱") ("ft/" nil "粋")
	("gt/" nil "遷") ("qt/" nil "筑") ("wt/" nil "韻")
	("et/" nil "削") ("rt/" nil "孔") ("tt/" nil "巌")
	("ztl" nil "粘") ("xtl" nil "恥") ("ctl" nil "剣")
	("vtl" nil "澄") ("btl" nil "崇") ("atl" nil "照")
	("stl" nil "銘") ("dtl" nil "漁") ("ftl" nil "桜")
	("gtl" nil "宣") ("qtl" nil "詰") ("wtl" nil "双")
	("etl" nil "属") ("rtl" nil "抗") ("ttl" nil "伴")
	("zt;" nil "鞄") ("xt;" nil "逝") ("ct;" nil "覆")
	("vt;" nil "甚") ("bt;" nil "坦") ("at;" nil "旨")
	("st;" nil "凍") ("dt;" nil "脱") ("ft;" nil "唱")
	("gt;" nil "毒") ("qt;" nil "寸") ("wt;" nil "軒")
	("et;" nil "脳") ("rt;" nil "跡") ("tt;" nil "狂")
	("zto" nil "畝") ("xto" nil "倹") ("cto" nil "傑")
	("vto" nil "錬") ("bto" nil "斥") ("ato" nil "怪")
	("sto" nil "焦") ("dto" nil "綿") ("fto" nil "則")
	("gto" nil "踊") ("qto" nil "嫁") ("wto" nil "損")
	("eto" nil "隣") ("rto" nil "慶") ("tto" nil "既")
	("ztp" nil "莫") ("xtp" nil "窪") ("ctp" nil "垂")
	("vtp" nil "叔") ("btp" nil "汝") ("atp" nil "鶏")
	("stp" nil "譜") ("dtp" nil "勉") ("ftp" nil "充")
	("gtp" nil "緒") ("qtp" nil "嘆") ("wtp" nil "釈")
	("etp" nil "厳") ("rtp" nil "惑") ("ttp" nil "憩")
	("nyz" nil "塞") ("myz" nil "此") (",yz" nil "詫")
	("hyz" nil "燈") ("jyz" nil "仰") ("kyz" nil "較")
	("yyz" nil "橘") ("uyz" nil "綜") ("iyz" nil "戯")
	(".yz" nil "覗") ("/yz" nil "恕") ("lyz" nil "仇")
	(";yz" nil "該") ("oyz" nil "霞") ("pyz" nil "挿")
	("nyx" nil "憧") ("myx" nil "玲") (",yx" nil "侯")
	("hyx" nil "哀") ("jyx" nil "怒") ("kyx" nil "染")
	("yyx" nil "擬") ("uyx" nil "姫") ("iyx" nil "腸")
	(".yx" nil "桧") ("/yx" nil "斑") ("lyx" nil "於")
	(";yx" nil "碑") ("oyx" nil "斬") ("pyx" nil "慨")
	("nyc" nil "佃") ("myc" nil "旦") (",yc" nil "砕")
	("hyc" nil "畳") ("jyc" nil "項") ("kyc" nil "硝")
	("yyc" nil "駄") ("uyc" nil "煙") ("iyc" nil "症")
	(".yc" nil "韓") ("/yc" nil "蝕") ("lyc" nil "暑")
	(";yc" nil "斉") ("oyc" nil "鼻") ("pyc" nil "但")
	("nyv" nil "曳") ("myv" nil "曲") (",yv" nil "伍")
	("hyv" nil "桃") ("jyv" nil "吾") ("kyv" nil "臣")
	("yyv" nil "鎮") ("uyv" nil "慎") ("iyv" nil "拠")
	(".yv" nil "頚") ("/yv" nil "畠") ("lyv" nil "泥")
	(";yv" nil "栽") ("oyv" nil "滅") ("pyv" nil "疾")
	("nyb" nil "蟹") ("myb" nil "挺") (",yb" nil "肯")
	("hyb" nil "綾") ("jyb" nil "伎") ("kyb" nil "疲")
	("yyb" nil "膚") ("uyb" nil "昔") ("iyb" nil "栗")
	(".yb" nil "燭") ("/yb" nil "狸") ("lyb" nil "悦")
	(";yb" nil "偏") ("oyb" nil "詞") ("pyb" nil "懐")
	("nya" nil "猪") ("mya" nil "篭") (",ya" nil "尋")
	("hya" nil "掲") ("jya" nil "岳") ("kya" nil "寿")
	("yya" nil "稚") ("uya" nil "賛") ("iya" nil "貨")
	(".ya" nil "鯛") ("/ya" nil "璃") ("lya" nil "獄")
	(";ya" nil "冒") ("oya" nil "鋭") ("pya" nil "潤")
	("nys" nil "吟") ("mys" nil "壮") (",ys" nil "随")
	("hys" nil "薄") ("jys" nil "秒") ("kys" nil "攻")
	("yys" nil "陶") ("uys" nil "暴") ("iys" nil "郡")
	(".ys" nil "禍") ("/ys" nil "塊") ("lys" nil "像")
	(";ys" nil "輝") ("oys" nil "貴") ("pys" nil "幼")
	("nyd" nil "艇") ("myd" nil "乾") (",yd" nil "緊")
	("hyd" nil "湯") ("jyd" nil "闘") ("kyd" nil "邦")
	("yyd" nil "群") ("uyd" nil "苦") ("iyd" nil "模")
	(".yd" nil "宴") ("/yd" nil "逸") ("lyd" nil "酸")
	(";yd" nil "柄") ("oyd" nil "票") ("pyd" nil "途")
	("nyf" nil "暁") ("myf" nil "秩") (",yf" nil "仁")
	("hyf" nil "呼") ("jyf" nil "疑") ("kyf" nil "衆")
	("yyf" nil "否") ("uyf" nil "察") ("iyf" nil "希")
	(".yf" nil "眺") ("/yf" nil "慈") ("lyf" nil "札")
	(";yf" nil "甲") ("oyf" nil "背") ("pyf" nil "沼")
	("nyg" nil "賊") ("myg" nil "頂") (",yg" nil "吸")
	("hyg" nil "絡") ("jyg" nil "仏") ("kyg" nil "姿")
	("yyg" nil "荷") ("uyg" nil "速") ("iyg" nil "邸")
	(".yg" nil "逐") ("/yg" nil "枯") ("lyg" nil "丹")
	(";yg" nil "避") ("oyg" nil "刺") ("pyg" nil "束")
	("nyq" nil "臼") ("myq" nil "跳") (",yq" nil "慕")
	("hyq" nil "匹") ("jyq" nil "旬") ("kyq" nil "潟")
	("yyq" nil "玄") ("uyq" nil "鑑") ("iyq" nil "僚")
	(".yq" nil "蜂") ("/yq" nil "曙") ("lyq" nil "扇")
	(";yq" nil "尻") ("oyq" nil "耳") ("pyq" nil "傍")
	("nyw" nil "洩") ("myw" nil "拘") (",yw" nil "乙")
	("hyw" nil "皇") ("jyw" nil "飾") ("kyw" nil "博")
	("yyw" nil "氷") ("uyw" nil "茂") ("iyw" nil "粉")
	(".yw" nil "悔") ("/yw" nil "晃") ("lyw" nil "届")
	(";yw" nil "敏") ("oyw" nil "貯") ("pyw" nil "我")
	("nye" nil "猶") ("mye" nil "遣") (",ye" nil "霧")
	("hye" nil "湖") ("jye" nil "採") ("kye" nil "境")
	("yye" nil "植") ("uye" nil "去") ("iye" nil "易")
	(".ye" nil "紺") ("/ye" nil "逓") ("lye" nil "併")
	(";ye" nil "卸") ("oye" nil "章") ("pye" nil "超")
	("nyr" nil "鼓") ("myr" nil "欄") (",yr" nil "肩")
	("hyr" nil "仙") ("jyr" nil "離") ("kyr" nil "借")
	("yyr" nil "暗") ("uyr" nil "訴") ("iyr" nil "鳥")
	(".yr" nil "悠") ("/yr" nil "弧") ("lyr" nil "執")
	(";yr" nil "駒") ("oyr" nil "呈") ("pyr" nil "曹")
	("nyt" nil "枢") ("myt" nil "薩") (",yt" nil "顧")
	("hyt" nil "描") ("jyt" nil "功") ("kyt" nil "夕")
	("yyt" nil "暗") ("uyt" nil "訴") ("iyt" nil "枚")
	(".yt" nil "窃") ("/yt" nil "卑") ("lyt" nil "菊")
	(";yt" nil "那") ("oyt" nil "巡") ("pyt" nil "飼")
	))

(if skk-tutcode-use-touch16+
    (setq skk-rom-kana-rule-list
	  (nconc '(("tld" nil "ぱ") ("tle" nil "ぴ") ("tlr" nil "ぷ")
		   ("tlg" nil "ぺ") ("tlf" nil "ぽ") ("dlr" nil "づ")
		   ("alu" nil "ヴ") ("eld" nil "ヵ") ("elg" nil "ヶ") )
		 skk-rom-kana-rule-list )))

(provide 'skk-tutcdef)
;;; skk-tutcdef.el ends here
