RCS
CVS
not_used
*,v
*.elc
*.bak
make.log
temp.el
dic/SKK-JISYO.E2J
dic/SKK-JISYO.pubdic+
dic/edict.doc
jisyo-tools
experimental/rdbms/kanjidic/kanjidic
experimental/rdbms/kanjidic/kanjidic.doc
experimental/rdbms/kanjidic/kanjid212
experimental/rdbms/kanjidic/kanjid212.doc
experimental/rdbms/00INDEX.html#dic_fil
experimental/rdbms/pubdic+/COPYRIGHT
experimental/rdbms/pubdic+/Imakefile
experimental/rdbms/pubdic+/README
experimental/rdbms/pubdic+/README.jp
experimental/rdbms/pubdic+/VERSION
experimental/rdbms/pubdic+/ctopd.c
experimental/rdbms/pubdic+/pod.c
experimental/rdbms/pubdic+/pod.jmn
experimental/rdbms/pubdic+/ps.tab
experimental/rdbms/pubdic+/pubdic.p
experimental/rdbms/pubdic+/pubdic.p.diff
experimental/rdbms/pubdic+/special.p
experimental/rdbms/pubdic+/wc.tab
experimental/rdbms/pubdic+/wtopd.c
experimental/rdbms/tmp/busyu_data.txt
experimental/rdbms/tmp/busyu_base.txt
experimental/rdbms/tmp/hinsi_data.txt
experimental/rdbms/tmp/jis2.txt
experimental/rdbms/tmp/kcode.txt
experimental/rdbms/tmp/large.txt
experimental/rdbms/tmp/private.txt
experimental/rdbms/tmp/stroke.txt
experimental/rdbms/tmp/temp.txt
experimental/tut-code/text
